@@ -4,10 +4,9 @@ class Job:
     """
     _ms: int
     _length: int
-    _file_size: int
     _schedule: int
 
-    def __init__(self, ms: int, length: int, file_size: int, schedule: int):
+    def __init__(self, ms: int, length: int,schedule: int):
         """
         Create a new Job with the given ms, length, file_size, schedule specified.
 
@@ -18,7 +17,6 @@ class Job:
         """
         self._ms = ms
         self._length = length
-        self._file_size = file_size
         self._schedule = schedule
 
     @property
@@ -29,10 +27,6 @@ class Job:
     def length(self):
         return self._length
 
-    @property
-    def file_size(self):
-        return self._file_size
-
     @property
     def schedule(self):
         return self._schedule
